@@ -1743,7 +1743,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
     def help1(self):
 
         import os
-        from orangecontrib.xoppy.util.text_window import TextWindow
+        from orangecontrib.xoppy.widgets.gui.text_window import TextWindow
         # from orangecontrib.xoppy.util.xoppy_util import locations
 
         home_doc = locations.home_doc()
